| Title: | Add Josa Based on Previous Letter in Korean |
|---|---|
| Description: | Josa in Korean is often determined by judging the previous word. When writing reports using Rmd, a function that prints the appropriate investigation for each case is helpful. The 'josaplay' package then evaluates the previous word to determine which josa is appropriate. |
| Authors: | Chanyub Park [aut, cre] (ORCID: <https://orcid.org/0000-0001-6474-2570>) |
| Maintainer: | Chanyub Park <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.1 |
| Built: | 2026-05-11 06:59:11 UTC |
| Source: | https://github.com/mrchypark/josaplay |
prefix jsp_ functions work support gwawa, eunneun, iga, eulleul
jsp_gwawa(textko) jsp_eunneun(textko) jsp_iga(textko) jsp_eulleul(textko)jsp_gwawa(textko) jsp_eunneun(textko) jsp_iga(textko) jsp_eulleul(textko)
textko |
target text in Korean encoding UTF-8 |
jsp_gwawa("134") jsp_eulleul(15)jsp_gwawa("134") jsp_eulleul(15)
josa support
josa(textko, select)josa(textko, select)
textko |
target text in Korean encoding UTF-8 |
select |
Joso that need to select. |